Miscellaneous
=============

.. _kcu-label:

Line types
----------

Threedicore flow lines are classified by so called kcu types. They describe
certain characteristics or relationships between calculation nodes. To 'translate'
the kcu class to a more verbose string representation you can use the
``KCUDescriptor``.


.. automodule:: threedigrid.admin.utils
   :members: KCUDescriptor

